@@ -106,8 +106,8 @@ class CfgYaml:
         """
         config parser
         @path: config file path
-        @profile: the selected profile
-        @addprofiles: included profiles
+        @profile: the selected profile names
+        @addprofiles: included profiles names (list)
         @reloading: true when reloading
         @debug: debug flag
         """
@@ -140,6 +140,11 @@ class CfgYaml:
                 self._dbg(err)
             raise YamlException(err)
 
+        self._dbg('START of config parsing')
+        self._dbg('reloading: {}'.format(reloading))
+        self._dbg('profile: {}'.format(profile))
+        self._dbg('included profiles: {}'.format(','.join(self._inc_profiles)))
+
         self._yaml_dict = self._load_yaml(self._path)
         # live patch deprecated entries
         self._fix_deprecated(self._yaml_dict)
@@ -181,14 +186,16 @@ class CfgYaml:
         self._redefine_templater()
 
         if self._debug:
-            self._debug_dict('current variables defined', self.variables)
+            title = 'current variables defined'
+            self._debug_dict(title, self.variables)
 
         # parse the "profiles" block
         self.profiles = self._parse_blk_profiles(self._yaml_dict)
 
         # include the profile's variables/dynvariables last
         # as it overwrites existing ones
-        self._inc_profiles, pvar, pdvar = self._get_profile_included_vars()
+        incpro, pvar, pdvar = self._get_profile_included_vars()
+        self._inc_profiles = uniq_list(self._inc_profiles + incpro)
         self._add_variables(pvar, prio=True)
         self._add_variables(pdvar, shell=True, prio=True)
         self._profilevarskeys.extend(pvar.keys())
@@ -197,7 +204,8 @@ class CfgYaml:
         # template variables
         self.variables = self._template_dict(self.variables)
         if self._debug:
-            self._debug_dict('current variables defined', self.variables)
+            title = 'variables defined (after template dict)'
+            self._debug_dict(title, self.variables)
 
         ##################################################
         # template the "include" entries
@@ -205,7 +213,8 @@ class CfgYaml:
 
         self._template_include_entry()
         if self._debug:
-            self._debug_dict('current variables defined', self.variables)
+            title = 'variables defined (after template include)'
+            self._debug_dict(title, self.variables)
 
         ##################################################
         # parse the other blocks
@@ -264,6 +273,7 @@ class CfgYaml:
         if self._debug:
             self._dbg('########### {} ###########'.format('final config'))
             self._debug_entries()
+            self._dbg('END of config parsing')
 
     ########################################################
     # public methods
@@ -967,6 +977,8 @@ class CfgYaml:
         """import config from path"""
         if self._debug:
             self._dbg('import config from {}'.format(path))
+            self._dbg('profile: {}'.format(self._profile))
+            self._dbg('included profiles: {}'.format(self._inc_profiles))
         sub = CfgYaml(path, profile=self._profile,
                       addprofiles=self._inc_profiles,
                       debug=self._debug)
@@ -984,7 +996,8 @@ class CfgYaml:
 
         # merge top entries
         self.dotfiles = self._merge_dict(self.dotfiles, sub.dotfiles)
-        self.profiles = self._merge_dict(self.profiles, sub.profiles)
+        self.profiles = self._merge_dict(self.profiles, sub.profiles,
+                                         deep=True)
         self.actions = self._merge_dict(self.actions, sub.actions)
         self.trans_r = self._merge_dict(self.trans_r, sub.trans_r)
         self.trans_w = self._merge_dict(self.trans_w, sub.trans_w)
@@ -1124,7 +1137,7 @@ class CfgYaml:
         """load a yaml file to a dict"""
         content = {}
         if self._debug:
-            self._dbg('----------start:{}----------'.format(path))
+            self._dbg('----------dump:{}----------'.format(path))
             cfg = '\n'
             with open(path, 'r', encoding='utf8') as file:
                 for line in file:
@@ -1268,6 +1281,8 @@ class CfgYaml:
         pro = self.profiles.get(self._profile, [])
         if pro:
             pdfs = list(pro.get(self.key_profile_dotfiles, []))
+
+        # and any included profiles
         for addpro in self._inc_profiles:
             pro = self.profiles.get(addpro, [])
             if not pro:
@@ -1276,6 +1291,7 @@ class CfgYaml:
             pdfs.extend(pdfsalt)
             pdfs = uniq_list(pdfs)
 
+        # if ALL is defined
         if self.key_all not in pdfs:
             # take a subset of the dotfiles
             newdotfiles = {}
@@ -1427,13 +1443,38 @@ class CfgYaml:
         return list(chain.from_iterable(processed_paths))
 
     @classmethod
-    def _merge_dict(cls, high, low):
-        """merge high and low dict"""
+    def _merge_dict(cls, high, low, deep=False):
+        """
+        both dict must be the same form/type
+        if deep is True, then merge recursively
+        """
         if not high:
             high = {}
         if not low:
             low = {}
-        return {**low, **high}
+        if not high and not low:
+            return {}
+
+        if not deep:
+            return {**low, **high}
+
+        final = high.copy()
+        for k, val in low.items():
+            if isinstance(val, dict):
+                # content is dict, recurse
+                if k not in final:
+                    final[k] = {}
+                final[k] = cls._merge_dict(val, final[k], deep=True)
+            elif isinstance(val, list):
+                # content is list, merge
+                if k not in final:
+                    final[k] = []
+                final[k] += val
+            else:
+                # don't know how to handle
+                err = 'unable to merge'
+                raise YamlException(err)
+        return final
 
     @classmethod
     def _get_entry(cls, dic, key, mandatory=True):
@@ -1500,7 +1541,7 @@ class CfgYaml:
             if self._debug:
                 msg = 'normalizing relative to cfg: {} -> {}'
                 self._dbg(msg.format(path, ret))
-            return ret
+            path = ret
         ret = os.path.normpath(path)
         if self._debug and path != ret:
             self._dbg('normalizing: {} -> {}'.format(path, ret))
@@ -1557,10 +1598,16 @@ class CfgYaml:
         if not elems:
             return
         for k, val in elems.items():
-            self._dbg('\t- \"{}\": {}'.format(k, val))
+            if isinstance(val, dict):
+                self._dbg('  - \"{}\"'.format(k))
+                for subkey, sub in val.items():
+                    self._dbg('    * {}: \"{}\"'.format(subkey, sub))
+            else:
+                self._dbg('  - \"{}\": {}'.format(k, val))
 
     def _dbg(self, content):
-        pre = os.path.basename(self._path)
+        directory = os.path.basename(os.path.dirname(self._path))
+        pre = os.path.join(directory, os.path.basename(self._path))
         self._log.dbg('[{}] {}'.format(pre, content))
 
     def _save_uservariables(self, uvars):
